@@ -17,11 +17,11 @@ import mock
 
 from ironic_lib import disk_utils
 from oslo_concurrency import processutils
-from oslotest import base as test_base
 
 from ironic_python_agent import errors
 from ironic_python_agent.extensions import iscsi
 from ironic_python_agent import hardware
+from ironic_python_agent.tests.unit import base
 from ironic_python_agent import utils
 
 
@@ -35,7 +35,7 @@ class FakeAgent(object):
 @mock.patch.object(utils, 'execute', autospec=True)
 @mock.patch.object(iscsi.rtslib_fb, 'RTSRoot',
                    mock.Mock(side_effect=iscsi.rtslib_fb.RTSLibError()))
-class TestISCSIExtensionTgt(test_base.BaseTestCase):
+class TestISCSIExtensionTgt(base.IronicAgentTest):
 
     def setUp(self):
         super(TestISCSIExtensionTgt, self).setUp()
@@ -134,6 +134,15 @@ class TestISCSIExtensionTgt(test_base.BaseTestCase):
         mock_execute.assert_has_calls(expected)
         mock_dispatch.assert_called_once_with('get_os_install_device')
 
+    def test_start_iscsi_target_fail_command_not_exist(self, mock_execute,
+                                                       mock_dispatch,
+                                                       mock_destroy):
+        mock_dispatch.return_value = self.fake_dev
+        mock_execute.side_effect = OSError('file not found')
+        self.assertRaises(errors.ISCSIError,
+                          self.agent_extension.start_iscsi_target,
+                          iqn=self.fake_iqn)
+
 
 _ORIG_UTILS = iscsi.rtslib_fb.utils
 
@@ -142,7 +151,7 @@ _ORIG_UTILS = iscsi.rtslib_fb.utils
 @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
 # Don't mock the utils module, as it contains exceptions
 @mock.patch.object(iscsi, 'rtslib_fb', utils=_ORIG_UTILS, autospec=True)
-class TestISCSIExtensionLIO(test_base.BaseTestCase):
+class TestISCSIExtensionLIO(base.IronicAgentTest):
 
     def setUp(self):
         super(TestISCSIExtensionLIO, self).setUp()
@@ -274,7 +283,7 @@ class TestISCSIExtensionLIO(test_base.BaseTestCase):
 
 
 @mock.patch.object(iscsi.rtslib_fb, 'RTSRoot', autospec=True)
-class TestISCSIExtensionCleanUp(test_base.BaseTestCase):
+class TestISCSIExtensionCleanUp(base.IronicAgentTest):
 
     def setUp(self):
         super(TestISCSIExtensionCleanUp, self).setUp()
